@@ -574,7 +574,7 @@ def uniform_kernel(x,mu_,var_):
 
 
 
-@jit('float64(float64[:,:], float64[:,:], float64[:,:],int64[:,:],float64[:,:,:],float64[:,:,:],float64[:],float64[:],float64[:],int64,float64[:])',nopython=True,cache=True)
+@jit('float64(float64[:,:], float64[:,:], float64[:,:],int64[:,:],float64[:,:,:],float64[:,:,:],float64[:],float64[:],float64[:],int64,float64[:])',nopython=True)
 def hdre_loss(X,y,w_,dim_combos, pdf_combos,bin_combos, min_lim, max_lim, param_to_dim, num_dim, widths):
      var =np.copy(np.abs(w_[:num_dim])).astype(np.float64)
 
